<?php declare(strict_types = 1);
/*
** Zabbix
** Copyright (C) 2001-2023 Zabbix SIA
** Copyright (C) 2024 Cybertrust Japan Co., Ltd.
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
**/


require_once dirname(__FILE__).'/../../include/forms.inc.php';

/**
 * Configuration snapshot edit controller for full-page form.
 */
class CControllerSnapshotEdit extends CController {

	/**
	 * Edited snapshot.
	 *
	 * @var ?array
	 */
	protected $snapshot;

	protected function init() {
		$this->disableSIDValidation();
	}

	protected function checkInput(): bool {
		$fields = [
			'snapshotid'		=> 'required|db snapshots.snapshotid'
		];

		$ret = $this->validateInput($fields);

		if (!$ret) {
			$this->setResponse(new CControllerResponseFatal());
		}

		return $ret;
	}

	protected function checkPermissions(): bool {
		$snapshots_type = DBfetchArray(DBSelect(
			'select type from snapshots where snapshotid='.
			$this->getInput('snapshotid').
			';'
		));

		switch ($snapshots_type[0]['type']) {
			case ZBX_SNAPSHOT_TYPE_HOST:
			case ZBX_SNAPSHOT_TYPE_TEMPLATE:
				return $this->checkSnapshotAccess();
			default:
				return false;
		}
	}

	protected function doAction(): void {
		$snapshots = DBfetchArray(DBSelect(
			'select snapshotid,name,created_at,type,description,members'.
			' from snapshots where snapshotid='.
			$this->getInput('snapshotid').
			';'
		));
		$this->snapshot = $snapshots[0];

		switch ($snapshots[0]['type']) {
			case ZBX_SNAPSHOT_TYPE_HOST:
				$backurl = (new CUrl('zabbix.php'))
					->setArgument('action', 'snapshot.host.list')
					->getUrl();
				break;
			case ZBX_SNAPSHOT_TYPE_TEMPLATE:
				$backurl = (new CUrl('zabbix.php'))
					->setArgument('action', 'snapshot.template.list')
					->getUrl();
				break;
			default:
				$backurl = CMenuHelper::getFirstUrl();
				break;
		}

		$data = [
			'form_action' => 'snapshot.update',
			'snapshotid' => $this->snapshot['snapshotid'],
			'snapshot' => $this->snapshot,
			'backurl' => $backurl,
			'user' => [
				'debug_mode' => $this->getDebugMode()
			]
		];

		$response = new CControllerResponseData($data);
		$response->setTitle(_('Snapshot'));
		$this->setResponse($response);
	}
}
