<?php declare(strict_types = 1);
/*
** Zabbix
** Copyright (C) 2001-2023 Zabbix SIA
** Copyright (C) 2024 Cybertrust Japan Co., Ltd.
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
**/


class CControllerSnapshotMassDelete extends CController {

	protected function checkInput(): bool {
		$fields = [
			'type' => 'required|in '.ZBX_SNAPSHOT_TYPE_HOST.','.ZBX_SNAPSHOT_TYPE_TEMPLATE,
			'snapshotids' => 'required|array_db snapshots.snapshotid'
		];

		$ret = $this->validateInput($fields);

		if (!$ret) {
			$this->setResponse(
				new CControllerResponseData(['main_block' => json_encode([
					'error' => [
						'title' => _('Cannot delete snapshot'),
						'messages' => array_column(get_and_clear_messages(), 'message')
					]
				])])
			);
		}

		return $ret;
	}

	protected function checkPermissions(): bool {
		switch ($this->getInput('type', ZBX_SNAPSHOT_TYPE_NONE)) {
			case ZBX_SNAPSHOT_TYPE_HOST:
			case ZBX_SNAPSHOT_TYPE_TEMPLATE:
				return $this->checkSnapshotAccess();
			default:
				return false;
		}
	}

	protected function doAction(): void {
		$snapshotids = $this->getInput('snapshotids');

		$snapshots_cnt = DBfetch(DBselect(
			'select count(*) as cnt from snapshots where snapshotid in (' .
			implode(',', array_values($snapshotids)) .
			');'
		));
		if ($snapshots_cnt['cnt'] == count($snapshotids)) {
			$result = DBexecute(
				'delete from snapshots where snapshotid in (' .
				implode(',', array_values($snapshotids)) .
				');'
			);
		}
		else {
			$result = false;
			error(_('No permissions to referred object or it does not exist!'));
		}

		$output = [];

		if ($result) {
			$success = ['title' => _('Snapshot deleted')];

			if ($messages = get_and_clear_messages()) {
				$success['messages'] = array_column($messages, 'message');
			}

			$output['success'] = $success;
		}
		else {
			CMessageHelper::setErrorTitle(_('Cannot delete snapshot'));

			$output['error'] = [
				'title' => CMessageHelper::getTitle(),
				'messages' => array_column(get_and_clear_messages(), 'message')
			];
		}

		$this->setResponse(new CControllerResponseData(['main_block' => json_encode($output)]));
	}
}
