<?php
/*
** Zabbix
** Copyright (C) 2001-2024 Zabbix SIA
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
**/


/**
 * @var CView $this
 */
?>

<script type="text/x-jquery-tmpl" id="filter-tag-row-tmpl">
	<?= CTagFilterFieldHelper::getTemplate(); ?>
</script>

<script type="text/javascript">
	jQuery(function($) {
		$('#filter-tags')
			.dynamicRows({template: '#filter-tag-row-tmpl'})
			.on('afteradd.dynamicRows', function() {
				var rows = this.querySelectorAll('.form_row');
				new CTagFilterItem(rows[rows.length - 1]);
			});

		// Init existing fields once loaded.
		document.querySelectorAll('#filter-tags .form_row').forEach(row => {
			new CTagFilterItem(row);
		});
	});
</script>

<script type="text/javascript">
	function createSnapshot(button, {templateids}) {
		const confirm_text = button.getAttribute('confirm');
		if (!confirm(confirm_text)) {
			return;
		}

		const curl = new Curl('zabbix.php');
		curl.setArgument('action', 'snapshot.create');

		fetch(curl.getUrl(), {
			method: 'POST',
			headers: {'Content-Type': 'application/x-www-form-urlencoded; charset=UTF-8'},
			body: urlEncodeData({type: <?= ZBX_SNAPSHOT_TYPE_TEMPLATE; ?>, hostids: templateids})
		})
			.then((response) => response.json())
			.then((response) => {
				if ('error' in response) {
					postMessageError(response.error.title);
					postMessageDetails('error', response.error.messages);
				}
				else if('success' in response) {
					postMessageOk(response.success.title);

					if ('messages' in response.success) {
						postMessageDetails('success', response.success.messages);
					}
				}

				location.href = location.href;
			})
			.catch(() => {
				const title = <?= json_encode(_('Unexpected server error.')) ?>;
				const message = <?= json_encode(_('Please check PHP memory limit setting')) ?>;
				const message_box = makeMessageBox('bad', message, title, true, true)[0];

				clearMessages();
				addMessage(message_box);
			})
	}
</script>
